# GNU Enterprise Common Library - Application Services
#
# Copyright 2001-2005 Free Software Foundation
#
# This file is part of GNU Enterprise
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or (at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# $Id: __init__.py 7281 2005-03-31 21:39:54Z reinhard $

"""
Basic services for all GNUe based applications
"""

# These modules introduce new functions into the builtins dictionary, so we
# always import them
import GDebug
import i18n
import errors
import checktype


# Add gStartupStatus global for startup status dialogs
__builtins__['gStartupStatus'] = lambda string:string


# Add the decimal class for python 2.3 or less
#if sys.hexversion < 0x02040000:
#  pth = sys.path
#  from gnue.common.external import decimal
#  sys.modules['decimal'] = decimal
#else:
#  import decimal
#
#__builtins__['Decimal'] = decimal.Decimal
